.. highlight:: shell-session

Quick start
===========

Ligo-raven requires Python >= 3.8 and a Linux or UNIX-like operating system. It
does not support Windows.

To install
----------

Ligo-raven can be installed via pip::

   $ pip install ligo-raven

The most current RAVEN in-development version is available from the git repository::

   $ git clone https://git.ligo.org/lscsoft/raven.git
   $ cd raven
   $ pip install -e .

To test
-------

To run the reviewed ligo-raven unit tests::

   $ python setup.py test

Authentication
~~~~~~~~~~~~~~

Since ligo-raven uses GraceDb, an up-to-date certificate is required and can be generated by::

   $ ligo-proxy-init albert.einstein
